%This code produces the bounds on the response margins reported in Table 5
%and Online Appendix Table A7.
%
%The program starts by reading in the empirical choice probabilities
%and having Matlab check that we didn't make mistakes coding the analytical
%bounds or ordering them (i.e. determining which of the possible 
%solutions actually binds). 
%
%We then construct Naive and Conservative confidence intervals on 
%individual response probabilities by bootstrapping the analytical bound 
%solutions. Then we move on to constructing confidence
%intervals on linear combinations of parameters.
%
%The last part of the code checks what happens when earnings range 2
%is split into two subranges.

clear


adj=1; %choose AU size adjustment (default is 1; other options are 0 and 2)


%load data    
if adj==0
    s=['DerivedData/TableA6a_mat.txt'];
    t1=['Table A6 Exact Size'];
    t2=['Table A7 Exact Size'];
    delete('Logs/TableA7a.txt');
    diary('Logs/TableA7a.txt');
elseif adj==1
    s=['DerivedData/Table4_mat.txt'];
    t1=['Table 4'];
    t2=['Table 5'];
    delete('Logs/Table5.txt');
    diary('Logs/Table5.txt');
elseif adj==2
    s=['DerivedData/TableA6b_mat.txt'];
    t1=['Table A6 Two Sizes Up'];
    t2=['Table A7 Two Sizes Up'];
    delete('Logs/TableA7b.txt');
    diary('Logs/TableA7b.txt'); 
end



    
data=importdata(s);

fullps=data.data(1,:); %first row is point estimate
bsdata=data.data(2:end,:); %subsequent rows are bootstrap estimates



%full sample values (should line up with Table 5)
%note: to avoid confusion, participation categories have been recoded 
%from n/p to 0/1.
%c/t suffix refers to control (AFDC) or treatment (JF) group
%e.g., p10_c is Prob(in earnings range 1 & off welfare|control group)

p10_c=fullps(1,4);
p20_c=fullps(1,6);
p01_c=fullps(1,8);
p11_c=fullps(1,10);
p21_c=fullps(1,12);

p10_t=fullps(1,3);
p20_t=fullps(1,5);
p01_t=fullps(1,7);
p11_t=fullps(1,9);
p21_t=fullps(1,11);


p00_c=1-p10_c-p20_c-p01_c-p11_c-p21_c;
p00_t=1-p10_t-p20_t-p01_t-p11_t-p21_t;


ps=['0n';'1n';'2n';'0p';'1p';'2p'];

p_t=[p00_t,p10_t,p20_t,p01_t,p11_t,p21_t]';
p_c=[p00_c,p10_c,p20_c,p01_c,p11_c,p21_c]';


disp(['============================================== (Premise) ', t1])
disp('Reweighted probabilities by treatment status')
ps=[ps repmat(char(9),6,1) num2str(p_t,'%6.3f') repmat(' ',6,1) num2str(p_c,'%6.3f')]




%bootstrap values
b01_c=bsdata(:,8);
b10_c=bsdata(:,4);
b11_c=bsdata(:,10);
b20_c=bsdata(:,6);
b21_c=bsdata(:,12);

b01_t=bsdata(:,7);
b10_t=bsdata(:,3);
b11_t=bsdata(:,9);
b20_t=bsdata(:,5);
b21_t=bsdata(:,11);

b00_c=1-b10_c-b20_c-b01_c-b11_c-b21_c;
b00_t=1-b10_t-b20_t-b01_t-b11_t-b21_t;

%Point Estimates of Bounds

%We start by double checking our math and letting the computer
%find the empirical upper and lower bounds


disp(['=========================================================', t2, ' panel (a)'])
disp('Constructing bound point estimates')

disp('Start by letting Matlab find binding constraints via LP')


%Building the linear system
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n
%(I repeat this for reference throughout the code)

%constraints
b=[p00_t-p00_c ;...
   p10_t-p10_c ;...
   p20_t-p20_c ;...
   (p01_c-p01_t)/p01_c ;...
   p21_t-p21_c];

A=[p01_c, -p00_c, zeros(1,7);...
   zeros(1,7), -p10_c, p01_c;...
   0, 0, p01_c, -p20_c, zeros(1,3),0,0;...
   1,0,1,0,1,1,0,0,1;...
   zeros(1,5),p01_c,-p21_c,0,0];


lb=NaN(9,1);
ub=NaN(9,1);
options=optimset('TolFun',1e-12);
for i=1:9
    s=['Lower #' int2str(i)];
    disp(s)
    f=zeros(1,9);
    f(i)=1;
    [x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
    lb(i)=x(i);
    %[lambda.lower lambda.upper]  
    %[lambda.eqlin;lambda.ineqlin]
    
    s=['Upper #' int2str(i)];
    disp(s)
    f(i)=-1;
    [x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
    ub(i)=x(i);
    %[lambda.lower lambda.upper]  
    %[lambda.eqlin;lambda.ineqlin]

end
disp('LP estimates')
s_lb=num2str(lb,'%6.3f');
s_ub=num2str(ub,'%6.3f');
B=[repmat('{',9,1) s_lb repmat(', ',9,1) s_ub repmat('}',9,1)];

pis=['0r0n' char(9) ; '0n1r' char(9) ; '0r2n' char(9) ; '2n1r' char(9) ; '0r1r' char(9) ; '0r2u' char(9) ; '2u1r' char(9) ; '1n1r' char(9) ; '0r1n' char(9)]; 
    



B=[pis B]


%verify analytical bounds
ub1=(p01_c-p01_t-(p21_t-p21_c))./p01_c;
ub2=(p00_c-p00_t+p01_c-p01_t-(p21_t-p21_c))./p00_c;
ub3=p20_t./p01_c;
ub4=1;
ub5=(p01_c-p01_t-(p21_t-p21_c))./p01_c;
ub6=p21_t./p01_c;
ub7=1;
ub8=(p10_c-p10_t+p01_c-p01_t+p21_c-p21_t)./p10_c;
ub9=(p01_c-p01_t+p21_c-p21_t)./p01_c;

lb1=0;
lb2=(p00_c-p00_t)./p00_c;
lb3=0;
lb4=(p20_c-p20_t)./p20_c;
lb5=0;
lb6=(p21_t-p21_c)./p01_c;
lb7=0;
lb8=(p10_c-p10_t)./p10_c;
lb9=0;

UB=[ub1;ub2;ub3;ub4;ub5;ub6;ub7;ub8;ub9];
LB=[lb1;lb2;lb3;lb4;lb5;lb6;lb7;lb8;lb9];

disp('Analytical estimates')
s_lb=num2str(lb,'%6.3f');
s_ub=num2str(ub,'%6.3f');
Banal=[repmat('{',9,1) s_lb repmat(', ',9,1) s_ub repmat('}',9,1)];
Banal=[pis Banal]


disp('Checking Analytical == LP...')
if all(all(Banal==B))==0
    error('Bounds not ordered properly');
end
fprintf('Success: computer agrees with us!\n\n')

%bootstrap bounds (Naive: Imbens & Manski)
N=length(bsdata);

ub1=(b01_c-b01_t-(b21_t-b21_c))./b01_c;
ub2=(b00_c-b00_t+b01_c-b01_t-(b21_t-b21_c))./b00_c;
ub3=b20_t./b01_c;
ub4=1*ones(N,1);
ub5=(b01_c-b01_t-(b21_t-b21_c))./b01_c;
ub6=b21_t./b01_c;
ub7=1*ones(N,1);
ub8=(b10_c-b10_t+b01_c-b01_t+b21_c-b21_t)./b10_c;
ub9=(b01_c-b01_t+b21_c-b21_t)./b01_c;


lb1=0*ones(N,1);
lb2=(b00_c-b00_t)./b00_c;
lb3=0*ones(N,1);
lb4=(b20_c-b20_t)./b20_c;
lb5=0*ones(N,1);
lb6=(b21_t-b21_c)./b01_c;
lb7=0*ones(N,1);
lb8=(b10_c-b10_t)./b10_c;
lb9=0*ones(N,1);

BUB=[ub1,ub2,ub3,ub4,ub5,ub6,ub7,ub8,ub9];
BLB=[lb1,lb2,lb3,lb4,lb5,lb6,lb7,lb8,lb9];
L=LB-std(BLB)'*1.65;
U=UB+std(BUB)'*1.65;

disp('Naive CI')
B=num2str([L U],'%6.3f');
s_lb=num2str(max(0,L),'%6.3f');
s_ub=num2str(min(1,U),'%6.3f');
B=[repmat('[',9,1) s_lb repmat(', ',9,1) s_ub repmat(']',9,1)];


B=[pis B]


%bootstrap bounds (Conservative)
%Note: binding constraint ordered first

%Upper bound #1
bub11=(b01_c-b01_t+b21_c-b21_t)./b01_c;
bub12=b00_t./b01_c;
bub13=(b01_c-b01_t)./b01_c;
bub14=(b01_c-b01_t+b20_c-b20_t)./b01_c;
bub15=(b01_c-b01_t+b20_c-b20_t+b21_c-b21_t)./b01_c;
bub16=(b01_c-b01_t+b10_c-b10_t)./b01_c;
bub17=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t)./b01_c;
bub18=(b01_c-b01_t+b10_c-b10_t+b20_c-b20_t)./b01_c;
bub19=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t+b20_c-b20_t)./b01_c;

pub11=(p01_c-p01_t+p21_c-p21_t)./p01_c;
pub12=p00_t./p01_c;
pub13=(p01_c-p01_t)./p01_c;
pub14=(p01_c-p01_t+p20_c-p20_t)./p01_c;
pub15=(p01_c-p01_t+p20_c-p20_t+p21_c-p21_t)./p01_c;
pub16=(p01_c-p01_t+p10_c-p10_t)./p01_c;
pub17=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t)./p01_c;
pub18=(p01_c-p01_t+p10_c-p10_t+p20_c-p20_t)./p01_c;
pub19=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t+p20_c-p20_t)./p01_c;



BUB1=[bub11,bub12,bub13,bub14,bub15,bub16,bub17,bub18,bub19];
PUB1=[pub11,pub12,pub13,pub14,pub15,pub16,pub17,pub18,pub19];

T=bsxfun(@minus,BUB1,PUB1);

maxT=max(-T')';
r=quantile(maxT,.95);

UL1=pub11+r;


%Upper bound #2
bub21=(b00_c-b00_t+b01_c-b01_t-(b21_t-b21_c))./b00_c;
bub22=(b00_c-b00_t+b01_c-b01_t)./b00_c;
bub23=(b00_c-b00_t+b01_c-b01_t+b20_c-b20_t)./b00_c;
bub24=(b00_c-b00_t+b01_c-b01_t+b21_c-b21_t+b20_c-b20_t)./b00_c;
bub25=(b01_c-b01_t+b00_c-b00_t+b10_c-b10_t)./b00_c;
bub26=(b01_c-b01_t+b00_c-b00_t+b10_c-b10_t+b20_c-b20_t)./b00_c;
bub27=(b01_c-b01_t+b00_c-b00_t+b10_c-b10_t+b21_c-b21_t)./b00_c;
bub28=(b01_c-b01_t+b00_c-b00_t+b10_c-b10_t+b20_c-b20_t+b21_c-b21_t)./b00_c;



pub21=(p00_c-p00_t+p01_c-p01_t-(p21_t-p21_c))./p00_c;
pub22=(p00_c-p00_t+p01_c-p01_t)./p00_c;
pub23=(p00_c-p00_t+p01_c-p01_t+p20_c-p20_t)./p00_c;
pub24=(p00_c-p00_t+p01_c-p01_t+p21_c-p21_t+p20_c-p20_t)./p00_c;
pub25=(p01_c-p01_t+p00_c-p00_t+p10_c-p10_t)./p00_c;
pub26=(p01_c-p01_t+p00_c-p00_t+p10_c-p10_t+p20_c-p20_t)./p00_c;
pub27=(p01_c-p01_t+p00_c-p00_t+p10_c-p10_t+p21_c-p21_t)./p00_c;
pub28=(p01_c-p01_t+p00_c-p00_t+p10_c-p10_t+p20_c-p20_t+p21_c-p21_t)./p00_c;


BUB2=[bub21,bub22,bub23,bub24,bub25,bub26,bub27,bub28];
PUB2=[pub21,pub22,pub23,pub24,pub25,pub26,pub27,pub28];

T=bsxfun(@minus,BUB2,PUB2);

maxT=max(-T')';
r=quantile(maxT,.95);

UL2=pub21+r;


%Upper bound #3

bub31=b20_t./b01_c;
bub32=(b01_c-b01_t)./b01_c;
bub33=(b01_c-b01_t+b21_c-b21_t)./b01_c;
bub34=(b01_c-b01_t+b01_c-b01_t)./b01_c;
bub35=(b01_c-b01_t+b01_c-b01_t+b21_c-b21_t)./b01_c;
bub36=(b01_c-b01_t+b10_c-b10_t)./b01_c;
bub37=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t)./b01_c;
bub38=(b01_c-b01_t+b10_c-b10_t+b00_c-b00_t)./b01_c;
bub39=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t+b00_c-b00_t)./b01_c;

pub31=p20_t./p01_c;
pub32=(p01_c-p01_t)./p01_c;
pub33=(p01_c-p01_t+p21_c-p21_t)./p01_c;
pub34=(p01_c-p01_t+p01_c-p01_t)./p01_c;
pub35=(p01_c-p01_t+p01_c-p01_t+p21_c-p21_t)./p01_c;
pub36=(p01_c-p01_t+p10_c-p10_t)./p01_c;
pub37=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t)./p01_c;
pub38=(p01_c-p01_t+p10_c-p10_t+p00_c-p00_t)./p01_c;
pub39=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t+p00_c-p00_t)./p01_c;


BUB3=[bub31,bub32,bub33,bub34,bub35,bub36,bub37,bub38,bub39];
PUB3=[pub31,pub32,pub33,pub34,pub35,pub36,pub37,pub38,pub39];

T=bsxfun(@minus,BUB3,PUB3);

maxT=max(-T')';
r=quantile(maxT,.95);

UL3=pub31+r;


%Upper bound #5

bub51=(b01_c-b01_t+b21_c-b21_t)./b01_c;
bub52=(b01_c-b01_t)./b01_c;
bub53=(b01_c-b01_t+b00_c-b00_t)./b01_c;
bub54=(b01_c-b01_t+b20_c-b20_t)./b01_c;
bub55=(b01_c-b01_t+b21_c-b21_t+b20_c-b20_t)./b01_c;
bub56=(b01_c-b01_t+b00_c-b00_t+b20_c-b20_t)./b01_c;
bub57=(b01_c-b01_t+b00_c-b00_t+b20_c-b20_t+b21_c-b21_t)./b01_c;
bub58=(b01_c-b01_t+b00_c-b00_t+b21_c-b21_t)./b01_c;
bub59=(b01_c-b01_t+b10_c-b10_t)./b01_c;
bub510=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t)./b01_c;
bub511=(b01_c-b01_t+b10_c-b10_t+b20_c-b20_t)./b01_c;
bub512=(b01_c-b01_t+b10_c-b10_t+b00_c-b00_t)./b01_c;
bub513=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t+b00_c-b00_t)./b01_c;
bub514=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t+b20_c-b20_t)./b01_c;
bub515=(b01_c-b01_t+b10_c-b10_t+b21_c-b21_t+b20_c-b20_t+b00_c-b00_t)./b01_c;


pub51=(p01_c-p01_t+p21_c-p21_t)./p01_c;
pub52=(p01_c-p01_t)./p01_c;
pub53=(p01_c-p01_t+p00_c-p00_t)./p01_c;
pub54=(p01_c-p01_t+p20_c-p20_t)./p01_c;
pub55=(p01_c-p01_t+p21_c-p21_t+p20_c-p20_t)./p01_c;
pub56=(p01_c-p01_t+p00_c-p00_t+p20_c-p20_t)./p01_c;
pub57=(p01_c-p01_t+p00_c-p00_t+p20_c-p20_t+p21_c-p21_t)./p01_c;
pub58=(p01_c-p01_t+p00_c-p00_t+p21_c-p21_t)./p01_c;
pub59=(p01_c-p01_t+p10_c-p10_t)./p01_c;
pub510=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t)./p01_c;
pub511=(p01_c-p01_t+p10_c-p10_t+p20_c-p20_t)./p01_c;
pub512=(p01_c-p01_t+p10_c-p10_t+p00_c-p00_t)./p01_c;
pub513=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t+p00_c-p00_t)./p01_c;
pub514=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t+p20_c-p20_t)./p01_c;
pub515=(p01_c-p01_t+p10_c-p10_t+p21_c-p21_t+p20_c-p20_t+p00_c-p00_t)./p01_c;


BUB5=[bub51,bub52,bub53,bub54,bub55,bub56,bub57,bub58,bub59,bub510,bub511,bub512,bub513,bub514,bub515];
PUB5=[pub51,pub52,pub53,pub54,pub55,pub56,pub57,pub58,pub59,pub510,pub511,pub512,pub513,pub514,pub515];

T=bsxfun(@minus,BUB5,PUB5);

maxT=max(-T')';
r=quantile(maxT,.95);

UL5=pub51+r;


%Upper bound #6
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

bub61=b21_t./b01_c;
bub62=(b01_c-b01_t)./b01_c;
bub63=(b01_c-b01_t+b20_c-b20_t)./b01_c;
bub64=(b01_c-b01_t+b00_c-b00_t)./b01_c;
bub65=(b01_c-b01_t+b20_c-b20_t+b00_c-b00_t)./b01_c;
bub66=(b01_c-b01_t+b10_c-b10_t)./b01_c;
bub67=(b01_c-b01_t+b10_c-b10_t+b20_c-b20_t)./b01_c;
bub68=(b01_c-b01_t+b10_c-b10_t+b00_c-b00_t)./b01_c;
bub69=(b01_c-b01_t+b10_c-b10_t+b20_c-b20_t+b00_c-b00_t)./b01_c;

pub61=p21_t./p01_c;
pub62=(p01_c-p01_t)./p01_c;
pub63=(p01_c-p01_t+p20_c-p20_t)./p01_c;
pub64=(p01_c-p01_t+p00_c-p00_t)./p01_c;
pub65=(p01_c-p01_t+p20_c-p20_t+p00_c-p00_t)./p01_c;
pub66=(p01_c-p01_t+p10_c-p10_t)./p01_c;
pub67=(p01_c-p01_t+p10_c-p10_t+p20_c-p20_t)./p01_c;
pub68=(p01_c-p01_t+p10_c-p10_t+p00_c-p00_t)./p01_c;
pub69=(p01_c-p01_t+p10_c-p10_t+p20_c-p20_t+p00_c-p00_t)./p01_c;


BUB6=[bub61,bub62,bub63,bub64,bub65,bub66,bub67,bub68,bub69];
PUB6=[pub61,pub62,pub63,pub64,pub65,pub66,pub67,pub68,pub69];

T=bsxfun(@minus,BUB6,PUB6);

maxT=max(-T')';
r=quantile(maxT,.95);

UL6=pub61+r;

%Upper bound #8
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

bub81=(b10_c-b10_t+b01_c-b01_t+b21_c-b21_t)./b10_c;
bub82=(b10_c-b10_t+b01_c-b01_t)./b10_c;
bub83=(b10_c-b10_t+b01_c-b01_t+b00_c-b00_t)./b10_c;
bub84=(b10_c-b10_t+b01_c-b01_t+b20_c-b20_t)./b10_c;
bub85=(b10_c-b10_t+b01_c-b01_t+b00_c-b00_t+b21_c-b21_t)./b10_c;
bub86=(b10_c-b10_t+b01_c-b01_t+b00_c-b00_t+b20_c-b20_t)./b10_c;
bub87=(b10_c-b10_t+b01_c-b01_t+b21_c-b21_t+b20_c-b20_t)./b10_c;
bub88=(b10_c-b10_t+b01_c-b01_t+b00_c-b00_t+b21_c-b21_t+b20_c-b20_t)./b10_c;

pub81=(p10_c-p10_t+p01_c-p01_t+p21_c-p21_t)./p10_c;
pub82=(p10_c-p10_t+p01_c-p01_t)./p10_c;
pub83=(p10_c-p10_t+p01_c-p01_t+p00_c-p00_t)./p10_c;
pub84=(p10_c-p10_t+p01_c-p01_t+p20_c-p20_t)./p10_c;
pub85=(p10_c-p10_t+p01_c-p01_t+p00_c-p00_t+p21_c-p21_t)./p10_c;
pub86=(p10_c-p10_t+p01_c-p01_t+p00_c-p00_t+p20_c-p20_t)./p10_c;
pub87=(p10_c-p10_t+p01_c-p01_t+p21_c-p21_t+p20_c-p20_t)./p10_c;
pub88=(p10_c-p10_t+p01_c-p01_t+p00_c-p00_t+p21_c-p21_t+p20_c-p20_t)./p10_c;


BUB8=[bub81,bub82,bub83,bub84,bub85,bub86,bub87,bub88];
PUB8=[pub81,pub82,pub83,pub84,pub85,pub86,pub87,pub88];

T=bsxfun(@minus,BUB8,PUB8);

maxT=max(-T')';
r=quantile(maxT,.95);

UL8=pub81+r;


%Upper bound #9
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

bub91=(b01_c-b01_t+b21_c-b21_t)./b01_c;
bub92=b10_t./b01_c;
bub93=(b01_c-b01_t)./b01_c;
bub94=(b01_c-b01_t+b00_c-b00_t)./b01_c;
bub95=(b01_c-b01_t+b20_c-b20_t)./b01_c;
bub96=(b01_c-b01_t+b00_c-b00_t+b20_c-b20_t)./b01_c;
bub97=(b01_c-b01_t+b00_c-b00_t+b21_c-b21_t)./b01_c;
bub98=(b01_c-b01_t+b20_c-b20_t+b21_c-b21_t)./b01_c;
bub99=(b01_c-b01_t+b00_c-b00_t+b20_c-b20_t+b21_c-b21_t)./b01_c;

pub91=(p01_c-p01_t+p21_c-p21_t)./p01_c;
pub92=p10_t./p01_c;
pub93=(p01_c-p01_t)./p01_c;
pub94=(p01_c-p01_t+p00_c-p00_t)./p01_c;
pub95=(p01_c-p01_t+p20_c-p20_t)./p01_c;
pub96=(p01_c-p01_t+p00_c-p00_t+p20_c-p20_t)./p01_c;
pub97=(p01_c-p01_t+p00_c-p00_t+p21_c-p21_t)./p01_c;
pub98=(p01_c-p01_t+p20_c-p20_t+p21_c-p21_t)./p01_c;
pub99=(p01_c-p01_t+p00_c-p00_t+p20_c-p20_t+p21_c-p21_t)./p01_c;


BUB9=[bub91,bub92,bub93,bub94,bub95,bub96,bub97,bub98,bub99];
PUB9=[pub91,pub92,pub93,pub94,pub95,pub96,pub97,pub98,pub99];

T=bsxfun(@minus,BUB9,PUB9);

maxT=max(-T')';
r=quantile(maxT,.95);

UL9=pub91+r;




%Summary
disp('Upper Limits of Conservative CIs')
disp('(Note: lower limits same as under Naive)')

UL=[UL1;UL2;UL3;1;UL5;UL6;1;UL8;UL9];

s_ub=num2str(min(1,UL),'%6.3f');
B=[repmat('[',9,1) s_lb repmat(', ',9,1) s_ub repmat(']',9,1)];
B=[pis B]


reply = input('Basic results finished. Push a letter to continue','s');
       if isempty(reply)
           error('stopping because of empty response')
       end

       
       
%%%%%%%%%%%%%%%%%%%%%
%LINEAR COMBINATIONS%
%%%%%%%%%%%%%%%%%%%%%
fprintf('Moving on to linear combinations.. \n\n')
names=['estim' char(9); 'naive' char(9); 'consv' char(9)];


% TAKE UP WORK
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

disp('Not working -> Working (0 -> 1+)')
disp('LP bound estimates')

f=[0 p00_c p01_c 0 p01_c p01_c 0 0 p01_c]./(p01_c+p00_c);
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
lb(3)=fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]
    
f=-f;
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
ub(3)=-fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]

LPbound=[lb(3) ub(3)]


%analytical
disp('Analytical estimates')
disp('Note: in this case we are point identified')

pi0plushat=(p00_c+p01_c - (p00_t+p01_t))/(p01_c+p00_c)
s=std( (b00_c+b01_c - (b00_t+b01_t))./(b01_c+b00_c) )

ci=pi0plushat + [-1.96*s 1.96*s]





%TAKE UP WELFARE
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

disp('Off Welfare -> On Welfare (n -> p)')
disp('LP bound estimates')

f=[0 p00_c 0 p20_c zeros(1,3) p10_c 0]./(p00_c+p10_c+p20_c);
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
lb(2)=fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]
    
f=-f;
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
ub(2)=-fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]

LPbound=[lb(2) ub(2)]


%Lower Bound
plb=(p00_c-p00_t+p10_c-p10_t+p20_c-p20_t)./(p20_c+p10_c+p00_c);
blb=(b00_c-b00_t+b10_c-b10_t+b20_c-b20_t)./(b20_c+b10_c+b00_c);
L=plb-1.65*std(blb);

%Upper bound #8
bub81=(b00_c-b00_t+b10_c-b10_t+b20_c-b20_t+b01_c-b01_t+b21_c-b21_t)./(b20_c+b10_c+b00_c);
bub82=(b00_c-b00_t+b10_c-b10_t+b20_c-b20_t+b01_c-b01_t)./(b20_c+b10_c+b00_c);


pub81=(p00_c-p00_t+p10_c-p10_t+p20_c-p20_t+p01_c-p01_t+p21_c-p21_t)./(p20_c+p10_c+p00_c);
pub82=(p00_c-p00_t+p10_c-p10_t+p20_c-p20_t+p01_c-p01_t)./(p20_c+p10_c+p00_c);

BUB8=[bub81,bub82];
PUB8=[pub81,pub82];

T=bsxfun(@minus,BUB8,PUB8);

maxT=max(-T')';
r=quantile(maxT,.95);

UL8=pub81+r;
ULnaive=pub81+1.65*std(bub81);

disp('Analytical estimates')
disp('Note: first line should be same as LP')

B=['{' num2str(max(0,plb),'%6.3f') ',' num2str(min(1,pub81),'%6.3f') '}';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,ULnaive),'%6.3f') ']';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,UL8),'%6.3f') ']'];

B=[names B]





%EXIT WELFARE
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

disp('On welfare -> Off welfare (p -> n)')
%Lower Bound
plb=(p00_t-p00_c+p20_t-p20_c+p10_t-p10_c)./(p21_c+p11_c+p01_c);
blb=(b00_t-b00_c+b20_t-b20_c+b20_t-b10_c)./(b21_c+b11_c+b01_c);
L=plb-1.65*std(blb);

%Upper bound #8
bub91=(b01_c-b01_t+b21_c-b21_t)./(b01_c+b11_c+b21_c);
bub92=(b00_t+b20_t+b10_t)./(b01_c+b11_c+b21_c);
bub93=(b01_c-b01_t)./(b01_c+b11_c+b21_c);

pub91=(p01_c-p01_t+p21_c-p21_t)./(p01_c+p11_c+p21_c);
pub92=(p00_t+p20_t+p10_t)./(p01_c+p11_c+p21_c);
pub93=(p01_c-p01_t)./(p01_c+p11_c+p21_c);

BUB9=[bub91,bub92,bub93];
PUB9=[pub91,pub92,pub93];

T=bsxfun(@minus,BUB9,PUB9);

maxT=max(-T')';
r=quantile(maxT,.95);

UL9=pub91+r;
ULnaive=pub91+1.65*std(bub91);


disp('Analytical estimates')

B=['{' num2str(max(0,plb),'%6.3f') ',' num2str(min(1,pub91),'%6.3f') '}';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,ULnaive),'%6.3f') ']';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,UL9),'%6.3f') ']'];

B=[names B]




% EXIT WELFARE 2
%pi ordering: 0r0n, 0n1r, 0r2n, 2n1r, 0r1r, 0r2u, 2u1r, 1n1r, 0r1n

disp('On Welfare not working -> Off Welfare (0r -> n)')
disp('LP bound estimates')
clear ub lb
f=[1 0 1 zeros(1,5) 1];
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
lb(1)=fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]
    
f=-f;
[x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(9,1),ones(9,1),[],options);
ub(1)=-fval;
%[lambda.lower lambda.upper]  
%[lambda.eqlin;lambda.ineqlin]

LPbound=[lb(1) ub(1)]

%Lower Bound
plb=p00_t-p00_c+p20_t-p20_c+p10_t-p10_c;
blb=b00_t-b00_c+b20_t-b20_c+b10_t-b10_c;
L=plb-1.65*std(blb);

%Upper bound #7
bub71=(b01_c-b01_t+b21_c-b21_t)./b01_c;
bub72=(b00_t+b20_t+b10_t)./b01_c;
bub73=(b01_c-b01_t)./b01_c;

pub71=(p01_c-p01_t+p21_c-p21_t)./p01_c;
pub72=(p00_t+p20_t+p10_t)./p01_c;
pub73=(p01_c-p01_t)./p01_c;

BUB7=[bub71,bub72,bub73];
PUB7=[pub71,pub72,pub73];

T=bsxfun(@minus,BUB7,PUB7);

maxT=max(-T')';
r=quantile(maxT,.95);

UL7=pub71+r;
ULnaive=pub71+1.65*std(bub71);

disp('Analytical estimates')
disp('Note: first line should be same as LP')


B=['{' num2str(max(0,plb),'%6.3f') ',' num2str(min(1,pub71),'%6.3f') '}';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,ULnaive),'%6.3f') ']';...
   '[' num2str(max(0,L),'%6.3f') ',' num2str(min(1,UL7),'%6.3f') ']'];
B=[names B]


















%%%%%%%%%%%%%%%%%%%%%%%%
%Restricted Preferences%
%%%%%%%%%%%%%%%%%%%%%%%%

    
disp(['=========================================================', t2, ' panel (b)'])
disp('1n -> 1r under restricted utility specification')
disp('Note: we are point identified here')
pi_1n_1r_hat=-(p10_t-p10_c)/p10_c
b_pi_1n_1r=-(b10_t-b10_c)./b10_c;
s=std(b_pi_1n_1r)
lb=pi_1n_1r_hat-1.96*s;
ub=pi_1n_1r_hat+1.96*s;
ci=[lb ub]




       
       
       
       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SPLITTING EARNINGS RANGE 2 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if adj==1
    
 reply = input('Extended results finished. Push a letter to continue','s');
       if isempty(reply)
           error('stopping because of empty response')
       end   
    
disp('========================================================= Finer Earning Coarsening')
disp('')
disp('Range 2 is split into a lower range A (2 prime in paper) and an upper range B (2 double prime in paper)')

%here we use the default AU adjustment of 1

data=importdata('DerivedData/TableA8_mat.txt');

fullps=data.data(1,:); %first row is point estimate
bsdata=data.data(2:end,:); %subsequent rows are bootstrap estimates


%to decipher the names, now earnings range 2 is split
%into a lower range A (2' in paper) and an upper range B (2'' in paper)

%full sample 
p10_c=fullps(4);
pA0_c=fullps(6);
pB0_c=fullps(8);
p01_c=fullps(10);
p11_c=fullps(12);
pA1_c=fullps(14);
pB1_c=fullps(16);

p10_t=fullps(3);
pA0_t=fullps(5);
pB0_t=fullps(7);
p01_t=fullps(9);
p11_t=fullps(11);
pA1_t=fullps(13);
pB1_t=fullps(15);

p00_c=1-p10_c-pA0_c-pB0_c-p01_c-p11_c-pA1_c-pB1_c;
p00_t=1-p10_t-pA0_t-pB0_t-p01_t-p11_t-pA1_t-pB1_t;




%Point Estimates of Bounds
disp('Linear programming point estimates')

%pi ordering: 0r0n, 0n1r, 0rAn, 0rBn, An1r, Bn1r, 0r1r, 0rAu, 0rBu, Au1r, Bu1r, 1n1r, 0r1n



%constraints

b=[p00_t-p00_c ;...
   p10_t-p10_c ;...
   pA0_t-pA0_c ;...
   pB0_t-pB0_c ;...
   (p01_c-p01_t)./p01_c ;...
   pA1_t-pA1_c ;...
   pB1_t-pB1_c ];

A=[p01_c, -p00_c, zeros(1,11);...
   zeros(1,11), -p10_c, p01_c;...
   0, 0, p01_c, 0, -pA0_c, zeros(1,8);...
   0, 0, 0, p01_c, 0, -pB0_c, zeros(1,7);...
   1,0,1,1,0,0,1,1,1,0,0,0,1;...
   zeros(1,7),p01_c,0,-pA1_c,0,0,0;...
   zeros(1,8),p01_c,0,-pB1_c,0,0];


lb=NaN(13,1);
ub=NaN(13,1);
options=optimset('TolFun',1e-12);
for i=1:13
    s=['Lower #' int2str(i)];
    disp(s)
    f=zeros(1,13);
    f(i)=1;
    [x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(13,1),ones(13,1),[],options);
    lb(i)=x(i);
    
    s=['Upper #' int2str(i)];
    disp(s)
    f(i)=-1;
    [x,fval,exitflag,output,lambda]=linprog(f,[],[],A,b,zeros(13,1),ones(13,1),[],options);
    ub(i)=x(i);

end
disp('LP answer')

s_lb=num2str(lb,'%6.3f');
s_ub=num2str(ub,'%6.3f');
B=[repmat('{',13,1) s_lb repmat(', ',13,1) s_ub repmat('}',13,1)];


pis=['0r0n ' ;'0n1r '; '0rAn ' ;'0rBn '; 'An1r ' ; 'Bn1r ' ;'0r1r ' ;'0rAu '; '0rBu '; 'Au1r '; 'Bu1r '; '1n1r '; '0r1n ']; 
B=[pis repmat(char(9),13,1) B]


%BS lower bound for opt-in

bA0_t=bsdata(:,5);
bA0_c=bsdata(:,6);
bB0_t=bsdata(:,7);
bB0_c=bsdata(:,8);


disp('Opt-in Responses: lower bounds')
lbA=(pA0_c-pA0_t)./pA0_c
lbB=(pB0_c-pB0_t)./pB0_c

bsA=(bA0_c-bA0_t)./bA0_c;
bsB=(bB0_c-bB0_t)./bB0_c;

disp('Opt-in Responses: lower limits of confidence intervals')
LA=lbA-std(bsA)*1.65
LB=lbB-std(bsB)*1.65

end 



diary off


